functions library
This is a package for anyone who wish to have compile-time math functions and believe these functions should look like functions instead of extension type. Not optimized for run-time, for any run-time usage, use 'dart:math' instead.
Extension Types
- abs
- Return absolute value, always return double.
- acos
- Calculate arccosine value.
- asin
- Calculate arcsine value.
- atan
- Calculate arctangent value.
- atan2
- Mimic atan2 function.
- cbrt
- Calculate cubic root with high accuracy.
- cos
- Calculate cosine value in radius.
- cosh
- calculate hyperbolic cosine of d.
- cot
- Calculate cotangent value in radius.
- coth
- calculate hyperbolic cotangent of d.
- csc
- Calculate cosecant value in radius.
- csch
- calculate hyperbolic cosecant of d.
- degToRad
- Change degree to radian.
- erf
- calculate error function
- erfc
- calculate complementory error function
- exp
- Calculate exponent value.
- log
- Calculate natural log value.
- log10
- Calculate 10-based log value.
- log2
- Calculate 2-based log value.
- max
- Compare and return maximum value for up to 10 values, returns double.
- min
- Compare and return minimum value for up to 10 values, returns double.
- pow
- Calculate a^b.
- radToDeg
- Change radian to degree.
- rt5
- Calculate 5th root with high accuracy.
- rt7
- Calculate 7th root with high accuracy.
- sec
- Calculate secant value in radius.
- sech
- calculate hyperbolic secant of d.
- sgn
- Return signum(d), in double.
- sin
- Calculate sine value in radius.
- sinh
- calculate hyperbolic sine of d.
- sqrt
- Calculate square root with high accuracy.
- tan
- Calculate tangent value in radius.
- tanh
- calculate hyperbolic tangent of d.